@@ -4,22 +4,25 @@ import pprint
 
 class PPrintRecordFormatter(logging.Formatter):
     '''Pretty print the __dict__ of the log record.'''
-    def __init__(self, fmt=None, datefmt=None, options=None, indent=1, style='%'):
+    def __init__(self, fmt=None, datefmt=None, indent=1, style='%'):
         super(PPrintRecordFormatter, self).__init__(fmt=fmt,
                                                     datefmt=datefmt,
                                                     style=style)
 
-        self.indent = indent or options.get('indent') or 1
+        self.indent = indent
 
     def format(self, record):
         res_dict = record.__dict__.copy()
         message = record.getMessage()
         res_dict['message'] = message
-        res = pprint.pformat(res_dict, indent=self.indent)
+        rendered = super().format(record)
+        res = '\n'.join([rendered,
+                         pprint.pformat(res_dict, indent=self.indent)])
         return res
 
     def __repr__(self):
-        buf = '%s(fmt="%s", options=%s, indent=%s)' % (self.__class__.__name__,
-                                                       self._fmt, self.options,
-                                                       self.indent)
+        buf = '%s(fmt="%s", indent=%s, style=%s)' % (self.__class__.__name__,
+                                                     self._fmt,
+                                                     self.indent,
+                                                     self._style)
         return buf
